"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendError = exports.sendInternalError = exports.sendClientError = exports.getMissingProperties = exports.noSuchOption = exports.missingFields = exports.errors = void 0;
const backtrace_service_1 = require("backtrace-service");
const log = backtrace_service_1.Logger.getLogger();
exports.errors = {
    noSuchObject: { message: `no such object`, code: 4 },
    internalError: { message: `internal error`, code: 65536 },
    malformedRequest: { message: `malformed request`, code: 32768 },
};
function missingFields(fields) {
    return { message: `missing required field(s): ${fields}`, code: 10 };
}
exports.missingFields = missingFields;
function noSuchOption(type) {
    return { message: `no such option: ${type}`, code: 13 };
}
exports.noSuchOption = noSuchOption;
// Basic user input validation
function getMissingProperties(reqBody, requiredProps) {
    const missing = requiredProps.filter((requiredProp) => {
        return !reqBody[requiredProp];
    });
    if (missing.length > 0) {
        return missing.join(' ');
    }
    return false;
}
exports.getMissingProperties = getMissingProperties;
// For purely user-error, sends a client-friendly error to user (no Backtrace report)
function sendClientError(res, errorObject) {
    const r = { error: errorObject };
    return res.send(JSON.stringify(r));
}
exports.sendClientError = sendClientError;
// Report/log the real error, send internal server error to client.
function sendInternalError(res, err) {
    log.error(err); // Sends a Backtrace Report
    const r = { error: exports.errors.internalError };
    return res.send(JSON.stringify(r));
}
exports.sendInternalError = sendInternalError;
// Report error, and send to client
function sendError(res, err, attributes) {
    log.error(err, attributes); // Sends a Backtrace Report
    const r = { error: err.message };
    return res.send(JSON.stringify(r));
}
exports.sendError = sendError;
//# sourceMappingURL=errors.js.map